@@ -1,6 +1,6 @@
 /*
  *  tenace - bridge hand viewer and editor
- *  Copyright (C) 2005-2009 Christoph Berg <cb@df7cb.de>
+ *  Copyright (C) 2005-2013 Christoph Berg <cb@df7cb.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -54,6 +54,42 @@ card_is_good (board *b, card c)
 	/* NOT REACHED */
 }
 
+static int
+ns_is_vulnerable (int board_number)
+{
+	switch (board_number % 16) {
+		case 2:
+		case 4:
+		case 5:
+		case 7:
+		case 10:
+		case 12:
+		case 13:
+		case 15:
+			return 1;
+			break;
+	}
+	return 0;
+}
+
+static int
+ew_is_vulnerable (int board_number)
+{
+	switch (board_number % 16) {
+		case 0: /* actually 16 */
+		case 3:
+		case 4:
+		case 6:
+		case 7:
+		case 9:
+		case 10:
+		case 13:
+			return 1;
+			break;
+	}
+	return 0;
+}
+
 /* dealing with boards */
 
 void board_clear(board *b)
@@ -93,27 +129,29 @@ void board_set_contract(board *b, int level, suit trumps, seat declarer, int dou
 	calculate_target(b);
 }
 
-board *board_new(void)
+board *board_new (int board_number) /* user-visible board number 1.. */
 {
 	int i;
 	char *names[] = {"West", "North", "East", "South"};
 	board *b = calloc (1, sizeof(board));
 	assert(b);
 
-	b->name = g_string_new("Board 1");
-	b->n = 0; /* will be set by the board menu hander */
+	b->name = g_string_new(NULL);
+	/* newly created board */
+	g_string_printf (b->name, _("Board %d"), board_number);
 	for (i = 0; i < 4; i++) {
 		b->hand_name[i] = g_string_new (_(names[i]));
 	}
 
-	b->dealer = north;
-	board_set_contract(b, 1, NT, south, 0);
+	b->dealer = DEALER (board_number);
+	board_set_contract(b, 1, NT, south, 0); /* default contract is 1NT by south */
 	b->current_dd = NULL;
 	for (i = 0; i < 52; i++) {
 		b->next_dd[i] = NULL;
 	}
 	board_clear(b);
-	b->vuln[0] = b->vuln[1] = 0;
+	b->vuln[0] = ns_is_vulnerable (board_number);
+	b->vuln[1] = ew_is_vulnerable (board_number);
 
 	b->bidding = calloc(4, sizeof(card));
 	assert(b->bidding);
