@@ -1,6 +1,6 @@
 /*
  *  tenace - bridge hand viewer and editor
- *  Copyright (C) 2005-2009 Christoph Berg <cb@df7cb.de>
+ *  Copyright (C) 2005-2013 Christoph Berg <cb@df7cb.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -215,6 +215,25 @@ char *contract_string_asc (int level, suit trumps, seat declarer, int doubled)
 	return buf;
 }
 
+char *vuln_string (board *b)
+{
+	if (b->vuln[0] == 0) {
+		if (b->vuln[1] == 0)
+			/* none vulnerable */
+			return _("none");
+		else
+			/* EW vulnerable */
+			return _("EW");
+	} else {
+		if (b->vuln[1] == 0) /* EW */
+			/* NS vulnerable */
+			return _("NS");
+		else
+			/* all vulnerable */
+			return _("all");
+	}
+}
+
 seat seat_mod(seat s)
 {
 	return ((s + 3) % 4) + 1;
