@@ -1,6 +1,6 @@
 /*
  *  tenace - bridge hand viewer and editor
- *  Copyright (C) 2005-2009 Christoph Berg <cb@df7cb.de>
+ *  Copyright (C) 2005-2012 Christoph Berg <cb@df7cb.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,15 +26,6 @@
 #include "window_board.h"
 #include "window_card.h"
 
-/* default paths */
-static char *svg_files[] = {
-	"bonded.svg",
-	"paris.svg",
-	"/usr/share/gnome-games-common/cards/bonded.svg", /* lenny */
-	"/usr/share/pixmaps/gnome-games-common/cards/bonded.svg", /* etch */
-	"/usr/share/gnome-games-common/cards/paris.svg", /* lenny */
-	"/usr/share/pixmaps/gnome-games-common/cards/paris.svg", /* etch */
-};
 static char *entry_name[] = { "entry_west", "entry_north", "entry_east", "entry_south" };
 
 static GtkWidget *window_options = NULL;
@@ -100,20 +91,18 @@ apply_options (GtkWidget *window_options)
 	w = get_widget ("show_as_cards");
 	int style = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)) ?
 		HAND_DISPLAY_STYLE_CARDS : HAND_DISPLAY_STYLE_TEXT;
-	board_window_set_style (win, style);
 	window_card_set_style (style);
-
 	w = get_widget ("svg_file");
 	gchar *fname = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (w));
-	w = get_widget ("spinbutton_card_width");
-	win->card_width = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (w));
-
-	if (fname) {
+	if (fname && strcmp (win->svg, fname)) { /* svg file changed */
 		if (win->svg)
 			g_free (win->svg);
 		win->svg = fname;
-		hand_display_set_svg (win->svg, win->card_width);
 	}
+	w = get_widget ("spinbutton_card_width");
+	int card_width = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (w));
+	board_window_set_style (win, style, card_width);
+	board_window_apply_style (win);
 
 	/* Hands */
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
@@ -184,7 +173,7 @@ read_config (window_board_t *win)
 {
 	char rcfile[1024];
 	snprintf (rcfile, sizeof (rcfile), "%s/%s",
-		g_get_user_config_dir (), "/tenacerc");
+		g_get_user_config_dir (), "tenacerc");
 
 	if (! g_key_file_load_from_file (win->keyfile, rcfile,
 		G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, NULL) &&
@@ -218,23 +207,6 @@ read_config (window_board_t *win)
 		win->show_played_cards = i;
 	}
 
-	/* check if the file is there */
-	struct stat buf;
-	if (win->svg) {
-		if (stat (win->svg, &buf) == -1) {
-			g_free (win->svg);
-			win->svg = NULL;
-		}
-	}
-	/* set a default */
-	if (! win->svg)
-		for (i = 0; i < sizeof (svg_files); i++) {
-			if (stat (svg_files[i], &buf) != -1) {
-				win->svg = strdup (svg_files[i]);
-				break;
-			}
-		}
-
 	/* Hands */
 
 	if ((p = g_key_file_get_string (win->keyfile, "tenace", "show_hands", NULL))) {
@@ -258,12 +230,6 @@ read_config (window_board_t *win)
 			win->show_dd_scores = seat_all;
 	}
 
-	board_window_set_style (win, win->hand_display_style);
-	window_card_set_style (win->hand_display_style);
-	if (win->hand_display_style == HAND_DISPLAY_STYLE_CARDS && win->svg) {
-		hand_display_set_svg (win->svg, win->card_width);
-	}
-
 	return 1;
 }
 
