@@ -1,6 +1,6 @@
 /*
  *  tenace - bridge hand viewer and editor
- *  Copyright (C) 2005-2009 Christoph Berg <cb@df7cb.de>
+ *  Copyright (C) 2005-2013 Christoph Berg <cb@df7cb.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ void init_solve()
 		physmem = 1;
 	/* cores to use */
 	int nproc = num_processors (NPROC_CURRENT_OVERRIDABLE);
-	printf ("Using %d GB RAM, %d cores\n", physmem, nproc);
+	g_debug ("Using %d GB RAM, %d cores\n", physmem, nproc);
 	InitStart(physmem, nproc);
 }
 
@@ -458,6 +458,7 @@ void parscore(board *b)
 char *
 par_label (board *b)
 {
+	/* parscore is pass */
 	GString *par = g_string_new(_("Par: PASS (0)\n"));
 	if (b->par_score != 0)
 		g_string_printf(par, _("Par: %s %s (%+d)\n"),
@@ -470,13 +471,17 @@ par_label (board *b)
 	for (t = 4; t >= 0; t--) {
 		g_string_append_printf(par, "%s: ", _(trump_str[t]));
 		if (b->par_arr[1][t] == b->par_arr[3][t])
+			/* parscore for NS */
 			g_string_append_printf(par, "%s<b>%d</b> ", _("NS"), b->par_arr[1][t]);
 		else
+			/* separate parscore for N and S */
 			g_string_append_printf(par, "%s<b>%d</b>%s<b>%d</b> ",
 					_("N"), b->par_arr[1][t], _("S"), b->par_arr[3][t]);
 		if (b->par_arr[0][t] == b->par_arr[2][t])
+			/* parscore for EW */
 			g_string_append_printf(par, "%s<b>%d</b>", _("EW"), b->par_arr[2][t]);
 		else
+			/* separate parscore for E and W */
 			g_string_append_printf(par, "%s<b>%d</b>%s<b>%d</b>",
 					_("E"), b->par_arr[2][t], _("W"), b->par_arr[0][t]);
 		if (t > 0)
