@@ -1,6 +1,6 @@
 /*
  *  tenace - bridge hand viewer and editor
- *  Copyright (C) 2005-2009 Christoph Berg <cb@df7cb.de>
+ *  Copyright (C) 2005-2013 Christoph Berg <cb@df7cb.de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/stat.h>
 
 #include "../handdisplay/hand_display.h"
 
@@ -33,6 +34,22 @@
 #include "window_line_entry.h"
 #include "window_play.h"
 
+/* default paths */
+static char *svg_files[] = {
+	"bonded.svg",
+	"paris.svg",
+	"/usr/share/aisleriot/cards/bonded.svgz", /* jessie: aisleriot package */
+	"/usr/share/aisleriot/cards/bonded.svg", /* wheezy: aislerot package */
+	"/usr/share/gnome-games-common/cards/bonded.svg", /* lenny */
+	"/usr/share/pixmaps/gnome-games-common/cards/bonded.svg", /* etch */
+	"/usr/share/aisleriot/cards/paris.svgz", /* jessie: gnome-cards-data package */
+	"/usr/share/aisleriot/cards/paris.svg", /* wheezy: gnome-cards-data package */
+	"/usr/share/gnome-games-common/cards/paris.svg", /* lenny */
+	"/usr/share/pixmaps/gnome-games-common/cards/paris.svg", /* etch */
+	"/usr/share/gnome-games-common/cards/gnomangelo_bitmap.svg", /* only file in gnome-cards-data in squeeze */
+	NULL
+};
+
 window_board_t *win; // FIXME static?
 int protect = 0;
 
@@ -76,9 +93,8 @@ board_window_rebuild_board_menu (window_board_t *win)
 		group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem));
 		if (i == win->cur)
 			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), TRUE);
-		win->boards[i]->n = i;
 		g_signal_connect (G_OBJECT (menuitem), "activate",
-			G_CALLBACK (board_menu_select), &(win->boards[i]->n));
+			G_CALLBACK (board_menu_select), &(win->board_numbers[i])); /* pointer to array index */
 
 		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), menuitem);
 		gtk_widget_show (menuitem);
@@ -187,8 +203,11 @@ void show_board (board *b, redraw_t redraw)
 
 	if (redraw & REDRAW_CONTRACT) {
 		w = get_widget ("label_board");
-		g_string_printf(str, "%s\n%s", b->name->str,
-			contract_string(b->level, b->trumps, b->declarer, b->doubled));
+		g_string_printf(str, "%s\n%s\n%s: %s\n%s: %s",
+			b->name->str,
+			contract_string(b->level, b->trumps, b->declarer, b->doubled),
+			_("Dealer"), _(seat_str[b->dealer]),
+			_("Vulnerable"), vuln_string(b));
 		gtk_label_set_text((GtkLabel*) w, str->str);
 
 		char *dealermenu[] = { 0, "dealer_west1", "dealer_north1",
@@ -599,14 +618,50 @@ create_bidding_widget (window_board_t *win)
 	gdk_colormap_alloc_color (cmap, &bidding_vuln, FALSE, TRUE);
 }
 
-void board_window_set_style (window_board_t *win, int style)
+void board_window_set_style (window_board_t *win, int style, int card_width)
 {
 	win->hand_display_style = style;
+	win->card_width = card_width;
+}
+
+void
+board_window_apply_style (window_board_t *win)
+{
+	/* check if the svg file is there */
+	if (win->svg) {
+		struct stat buf;
+		if (stat (win->svg, &buf) == -1) {
+			g_free (win->svg);
+			win->svg = NULL;
+		}
+	}
+
+	/* otherwise set a default */
+	if (! win->svg) {
+		int i;
+		for (i = 0; svg_files[i] != NULL; i++) {
+			struct stat buf;
+			if (stat (svg_files[i], &buf) != -1) {
+				win->svg = strdup (svg_files[i]);
+				break;
+			}
+		}
+	}
+
+	if (! win->svg && win->hand_display_style == HAND_DISPLAY_STYLE_CARDS) /* still nothing... */
+		win->hand_display_style = HAND_DISPLAY_STYLE_TEXT;
+
 	int h;
 	for (h = 0; h < 4; h++) {
-		hand_display_set_style(win->handdisp[h], style);
+		hand_display_set_style(win->handdisp[h], win->hand_display_style);
 	}
-	hand_display_set_style(win->table, style);
+	hand_display_set_style(win->table, win->hand_display_style);
+
+	window_card_set_style (win->hand_display_style);
+	if (win->hand_display_style == HAND_DISPLAY_STYLE_CARDS && win->svg) {
+		hand_display_set_svg (win->svg, win->card_width);
+	}
+
 	if (win->n_boards)
 		show_board(CUR_BOARD, REDRAW_HANDS);
 }
@@ -615,20 +670,25 @@ int
 board_window_append_board (window_board_t *win, board *b)
 {
 	if (!b) {
-		b = board_new ();
+		b = board_new (win->n_boards + 1);
 		g_string_printf (b->name, _("Board %d"), win->n_boards + 1);
 	}
 
 	if (! win->n_boards_alloc) {
-		win->n_boards_alloc = 4;
+		win->n_boards_alloc = 4; /* start with 4 entries */
 		win->boards = malloc (win->n_boards_alloc * sizeof (board *));
 		assert(win->boards);
+		win->board_numbers = malloc (win->n_boards_alloc * sizeof (int));
+		assert(win->board_numbers);
 	} else if (win->n_boards >= win->n_boards_alloc) {
 		win->n_boards_alloc <<= 2;
 		win->boards = realloc(win->boards, win->n_boards_alloc * sizeof (board*));
 		assert(win->boards);
+		win->board_numbers = realloc(win->board_numbers, win->n_boards_alloc * sizeof (int));
+		assert(win->board_numbers);
 	}
 	win->boards[win->n_boards] = b;
+	win->board_numbers[win->n_boards] = win->n_boards; /* store array index */
 	return win->n_boards++;
 }
 
@@ -663,11 +723,13 @@ board_window_init (window_board_t *win)
 	win->show_played_cards = 0;
 	win->show_hands = seat_all;
 	win->show_dd_scores = seat_all;
+	win->svg = NULL;
 	win->card_width = 70;
 
 	win->filename = NULL;
 	win->title = win->subtitle = win->team1 = win->team2 = NULL;
 	win->boards = NULL;
+	win->board_numbers = NULL;
 	win->n_boards_alloc = 0;
 	win->n_boards = 0;
 
@@ -731,7 +793,7 @@ board_set_dealer (seat dealer)
 	PROTECT_BEGIN;
 	board *b = CUR_BOARD;
 	b->dealer = dealer;
-	show_board(b, REDRAW_HANDS | REDRAW_NAMES | REDRAW_BIDDING);
+	show_board(b, REDRAW_CONTRACT | REDRAW_HANDS | REDRAW_NAMES | REDRAW_BIDDING);
 	PROTECT_END;
 }
 
